@@ -1,5 +1,5 @@
 package HackaMol::Molecule;
-$HackaMol::Molecule::VERSION = '0.023';
+$HackaMol::Molecule::VERSION = '0.024';
 #ABSTRACT: Molecule class for HackaMol
 use 5.008;
 use Moose;
@@ -231,17 +231,16 @@ HackaMol::Molecule - Molecule class for HackaMol
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
     use HackaMol;
     use Math::Vector::Real;
     
-    my $hack  = HackaMol->new(name => "hackitup");
-    my @atoms = $hack->read_file_atoms("t/lib/1L2Y.pdb"); 
+    my $mol  = HackaMol->new
+                       ->pdbid_mol('1L2Y');
     
-    my $mol = HackaMol::Molecule->new(name=> 'trp-cage', atoms=>[@atoms]);
     $mol->translate(-$mol->COM);
     $mol->rotate(V(1,0,0), 180, V(10,10,10));
     
